#### LOAD config_file
args = commandArgs(TRUE)
if (length(args) > 0) {
  configFile_path <- args[1]
} else {
  cat("\n***WARNING: no ConfigFile was provided. Using default ConfigFile.\n")
}
config       <- yaml::yaml.load_file(configFile_path)
file         <- config$file
nparams      <- config$nparams
sim_data     <- config$sim_data
image_folder <- config$image_folder
n_outputs    <- config$n_outputs
repo         <- config$repo
nsims 	     <- config$nsims_sobol
sobol_onPC   <- config$sobol_onPC
param_names  <- config$param_names
min_values   <- config$min_values
max_values   <- config$max_values

#print(param_names)
#stop
#### Load external functions
source(paste0(repo,"UQtools4es.R"))
library(gbm)
library(fOptions)
library(sensitivity)

#### Load data
reduced_train    <- readRDS(paste0(sim_data,"reduced_train.RDS"))
mypca            <- readRDS(paste0(sim_data,"mypca.RDS"))
data_to_validate <- readRDS(paste0(sim_data,"data_to_validate.RDS"))
c_gbm 		 <- readRDS(paste0(sim_data,"c_gbm.RDS"))

n_dim <- ncol(data_to_validate) - nparams # ouput dimenions

#####  Generate Random Sobol sequence of model parameters to analyze sensitivity #####
lds <- runif.sobol(n = nsims, dimension = nparams, scrambling = 3)
new_value <- lds
for (j in 1:nparams){
    new_value[,j] = min_values[j] + lds[,j]*( max_values[j] - min_values[j] )
}
new_value <- as.data.frame(new_value)
colnames(new_value) <- param_names

##### Perform sensitivity analysis based on the "new_value"  ####
## Randomly split data
sobol_size <- floor(0.5 * nrow(new_value))
random_index <- sample(seq_len(nrow(new_value)), size = sobol_size)
X1 <- new_value[random_index,]
X2 <- new_value[-random_index,]

if (sobol_onPC) {
## ANALYSIS on the Principal Components
	Sobol_global <- mulitple_sobol_onPC(surrogate_model_onPC,X1,X2,c_gbm)

	pdf(file = paste0(image_folder,"S1_on_PC.pdf"), width = 10, height = 6)
	barplot(t(as.matrix(Sobol_global[[1]])), main="First order Sobol indexes",
		xlab="Principal Components", col=rainbow(11),
		legend = colnames(Sobol_global[[1]]))
	dev.off()

	pdf(file = paste0(image_folder,"ST_on_PC.pdf"), width = 10, height = 6)
	barplot(t(as.matrix(Sobol_global[[2]])), main="Total order Sobol indexes",
		xlab="Principal Components", col=rainbow(11),
		legend = colnames(Sobol_global[[1]]))
	dev.off()

	Sobol_global2 <- mulitple_sobol_vjan(surrogate_model_onPC2,X1,X2, dim_output=n_outputs,c_gbm)

	pdf(file = paste0(image_folder,"S1_on_PC_vjan.pdf"), width = 10, height = 6)
	barplot(t(as.matrix(Sobol_global2[[1]])), main="First order Sobol indexes",
		xlab="Principal Components", col=rainbow(11),
		legend = colnames(Sobol_global[[1]]))
	dev.off()

	pdf(file = paste0(image_folder,"ST_on_PC_vjan.pdf"), width = 10, height = 6)
	barplot(t(as.matrix(Sobol_global2[[2]])), main="Total order Sobol indexes",
		xlab="Principal Components", col=rainbow(11),
		legend = colnames(Sobol_global[[1]]))
	dev.off()
}

## ANALYSIS on the physical space

Sobol_global3 <- mulitple_sobol_vjan(surrogate_model,X1,X2, dim_output=n_dim, c_gbm, mypca, n_outputs=n_outputs,i=NULL,log_data=TRUE)

#### save data
saveRDS(Sobol_global3,  file = paste0(sim_data,"Sobol_global3.RDS"))
